unit mTextbereich;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, mSuM;

type
  TTextbereich = class(TCustomMemo)

 private
    FFocusErhalten, FFocusVerloren, FInhaltGeaendert, FMarkierungGeaendert: tNotifyEvent;

    procedure setzeZustand(pAktiv:Wahrheitswert);
    procedure setzeSichtbarkeit(pSichtbar:Wahrheitswert);
    procedure setzeText(pInhalt:Zeichenkette);


  protected
    procedure doEnter; override;
    procedure doExit; override;
    procedure change; override;

  public

    constructor Create(AOwner: TComponent); override;
    constructor init(pLinks,pOben, pBreite, pHoehe: Zahl); virtual;

    procedure setzePosition(pLinks, pOben : Zahl); virtual;
    procedure setzeGroesse(pBreite, pHoehe : Zahl); virtual;

    function links:Zahl;  virtual;
    function oben:Zahl; virtual;
    function breite:Zahl;  virtual;
    function hoehe:Zahl; virtual;

    procedure verstecke; virtual;
    procedure zeige; virtual;
    function IstSichtbar:Wahrheitswert; virtual;

    procedure aktiviere; virtual;
    procedure deaktiviere; virtual;
    function istAktiviert: Wahrheitswert; virtual;

    procedure setzeFokus; virtual;
    function besitztFokus: Wahrheitswert; virtual;

    procedure setzeInhalt(pInhalt:Zeichenkette); virtual;
    procedure haengeZeichenAn(pInhalt:Zeichenkette);virtual;
    function inhalt:Zeichenkette; virtual;


    procedure setzeSchriftart(pArt:Zeichenkette);
    procedure setzeSchriftGroesse(pGroesse:GanzeZahl);
    procedure setzeSchriftFarbe(pFarbe:GanzeZahl);
    procedure setzeSchriftStil(pStil:GanzeZahl);

    procedure gibFrei; virtual;

    published

    property _Inhalt: Zeichenkette read inhalt
                             write setzeText;
    property _IstAktiviert : Wahrheitswert read istAktiviert write SetzeZustand;
    property _IstSichtbar : Wahrheitswert read IstSichtbar write SetzeSichtbarkeit;
    property font;
    property FocusErhalten : tNotifyEvent read FFocusErhalten write FFocusErhalten;
    property FocusVerloren : tNotifyEvent read FFocusVerloren write FFocusVerloren;
    property TextGeaendert : tNotifyEvent read FInhaltGeaendert write FInhaltGeaendert;

  end;

procedure Register;

implementation

constructor tTextbereich.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  self.ScrollBars:=ssBoth;
  self.setzeInhalt('');
end;

constructor tTextbereich.init(pLinks,pOben, pBreite, pHoehe: Zahl);
begin
  inherited create(screen.activeForm);
  ControlStyle := [csSetCaption, csOpaque, csDoubleClicks];
  TabStop := True;
  self.setzePosition(pLinks,pOben);
  self.setzeGroesse(pBreite,pHoehe);
  self.setzeText('');
  self.parent:=screen.activeForm;
end;

procedure tTextbereich.setzePosition(pLinks, pOben:Zahl);
begin
 self.left:=round(pLinks);
 self.Top:=round(pOben);
end;

procedure tTextbereich.setzeGroesse(pBreite, pHoehe:Zahl);
begin
 self.Width:=round(pBreite);
 self.Height:=round(pHoehe);
end;

function tTextbereich.links:Zahl;
begin
 result:=self.left
end;

function tTextbereich.oben:Zahl;
begin
  result:=self.top;
end;

function tTextbereich.breite:Zahl;
begin
  result:=self.width;
end;

function tTextbereich.hoehe:Zahl;
begin
  result:=self.height;
end;

procedure tTextbereich.verstecke;
begin
 self.visible:=false;
end;

procedure tTextbereich.zeige;
begin
 self.visible:=true;
end;

function tTextbereich.IstSichtbar:Wahrheitswert;
begin
  result:=self.visible;
end;

procedure tTextbereich.aktiviere;
begin
 self.enabled:=true;
end;

procedure tTextbereich.deaktiviere;
begin
 self.enabled:=false;
end;

function tTextbereich.istAktiviert: Wahrheitswert;
begin
 result:=self.enabled;
end;

procedure tTextbereich.setzeFokus;
begin
 screen.ActiveForm.FocusControl(self);
 self.AutoSelect:=true;
 self.SelectAll;
end;

function tTextbereich.besitztFokus: Wahrheitswert;
begin
 result:=self.focused;
end;

procedure tTextbereich.setzeText(pInhalt:Zeichenkette);
begin
 self.text:=pInhalt;
end;

procedure tTextbereich.haengeZeichenAn(pInhalt:Zeichenkette);
begin
  self.text:=self.text+pInhalt;
end;

procedure tTextbereich.setzeInhalt(pInhalt:Zeichenkette);
begin
 self.text:=pInhalt;
end;

function tTextbereich.Inhalt:Zeichenkette;
begin
 result := self.Text;
end;

procedure tTextbereich.setzeSchriftart(pArt:Zeichenkette);
begin
  self.Font.Name:=pArt;
end;

procedure tTextbereich.setzeSchriftGroesse(pGroesse:GanzeZahl);
begin
  self.Font.size:=pGroesse;
end;

procedure tTextbereich.setzeSchriftFarbe(pFarbe:GanzeZahl);
begin
  self.Font.Color:=SuMfarbumrechnung(pFarbe); {farbumrechnung aus mSuM}
end;

procedure tTextbereich.setzeSchriftStil(pStil:GanzeZahl);
begin
  self.Font.Style:=SuMstilumrechnung(pStil);  {stilumrechnung aus mSuM}
end;


procedure tTextbereich.gibFrei;
begin
 self.destroy;
end;

// private

procedure tTextbereich.setzeZustand(pAktiv:Wahrheitswert);
begin
 self.enabled:=pAktiv;
end;

procedure tTextbereich.SetzeSichtbarkeit(pSichtbar:Wahrheitswert);
begin
 self.visible:=pSichtbar;
end;

// Ereignisse

procedure tTextbereich.doEnter;
begin
  if assigned(FocusErhalten) then FocusErhalten(self);
  inherited doEnter;
end;

procedure tTextbereich.doExit;
begin
  if assigned(FocusVerloren) then FocusVerloren(self);
  inherited doExit;
end;

procedure tTextbereich.change;
begin
  if assigned(TextGeaendert) then TextGeaendert(self);
  inherited change;
end;

// Registrierung

procedure Register;
begin
  RegisterComponents('Schule', [tTextbereich]);
end;


end.
