unit mTextwerkzeug;
interface
uses Sysutils;
const
  CRLF=#$D#$A;
type
 Textwerkzeug = class(TObject)
                 private
                   zTrennung:ansiString;
                 public
                   constructor init;
                   procedure setzeTrennungsZeichen(pTrennung:string);
                   procedure setzeTrennung(pTrennung:string);
                   function laenge(pText:string):integer;
                   function zeichenAn(pText:string; pStelle:integer):char;
                   function wortAn(pText:string; wortNummer:integer):string;
                   function teilZeichenkette(pText:string; pVon, pBis:integer):string;
                   function positionVon(pText:string; pSuchtext:string):integer;
                   function textOhne(pText:string; pVon, pBis:integer):string;
                   function textMit(pText:string; pNeu:string; pStelle:integer):string;
                   function kleinschrift(pText:string):string;
                   function grossschrift(pText:string):string;
                   function istGleich(pText1,pText2:string):boolean;
                   function istKleiner(pText1,pText2:string):boolean;
                   function istGroesser(pText1,pText2:string):boolean;
                   function istZahl(pText:string):boolean;
                   function istGanzeZahl(pText:string):boolean;
                   function alsZahl(pText:string):double;
                   function alsGanzeZahl(pText:string):integer;
                   function alsText(pZahl:double):string; overload;
                   function alsText(pGanzeZahl:integer):string; overload;
                   function verkettung(pText1, pText2:string):string;
                   function dualInDezimal(pDualzahl:string):integer;
                   function dezimalInDual(pZahl:integer):string;
                   destructor gibFrei;
                 end;

implementation

  constructor Textwerkzeug.init;
  begin
    zTrennung:=' ';
    DecimalSeparator:='.';
  end;

  procedure Textwerkzeug.setzeTrennung(pTrennung:string);
  begin
    zTrennung:=pTrennung;
  end;

  procedure Textwerkzeug.setzeTrennungszeichen(pTrennung:string);
  begin
    self.setzeTrennung(pTrennung);
  end;

  function Textwerkzeug.laenge(pText:string):integer;
  begin
    result:=length(pText);
  end;

  function Textwerkzeug.zeichenAn(pText:string; pStelle:integer):char;
  begin
    result:=pText[pStelle];
  end;

  function Textwerkzeug.wortAn(pText:string; wortNummer:integer):string;
  var
    lText:string;
   begin
    if copy(pText,length(pText)-1,2)=CRLF then
      pText:=copy(pText,1,length(pText)-2);
    lText:=pText;
    while (ansiPos(zTrennung,lText)>0) and (wortNummer>1) do begin
      delete(lText,1,ansiPos(zTrennung,lText)+length(zTrennung)-1);
      dec(wortNummer);
    end;
    if wortNummer=1 then
      if ansiPos(zTrennung,lText)>0 then
        result:=copy(lText,1,ansiPos(zTrennung,lText)-1)
      else
        result:=lText
    else
      result:='';
  end;

  function Textwerkzeug.teilZeichenkette(pText:string; pVon, pBis:integer):string;
  begin
    result:=copy(pText,pVon,pBis-pVon+1);
  end;

  function Textwerkzeug.positionVon(pText:string; pSuchtext:string):integer;
  begin
    result:=ansiPos(pSuchtext,pText);
  end;

  function Textwerkzeug.textOhne(pText:string; pVon, pBis:integer):string;
  begin
    delete(pText,pVon,pBis-pVon+1);
    result:=pText;
  end;

  function Textwerkzeug.textMit(pText:string; pNeu:string; pStelle:integer):string;
  begin
    insert(pNeu,pText,pStelle);
    result:=pText;
  end;

  function Textwerkzeug.kleinschrift(pText:string):string;
  begin
    result:=ansiLowerCase(pText);
  end;

  function Textwerkzeug.grossschrift(pText:string):string;
  begin
    result:=ansiUpperCase(pText);
  end;

  function Textwerkzeug.istGleich(pText1,pText2:string):boolean;
  begin
    result:=ansiCompareStr(pText1,pText2)=0;
  end;

  function Textwerkzeug.istKleiner(pText1,pText2:string):boolean;
  begin
    result:=ansiCompareStr(pText1,pText2)<0;
  end;

  function Textwerkzeug.istGroesser(pText1,pText2:string):boolean;
  begin
    result:=ansiCompareStr(pText1,pText2)>0;
  end;

  function Textwerkzeug.istZahl(pText:string):boolean;
  var
    lZahl:double;
    lCode:integer;
  begin
    val(pText,lZahl,lCode);
    result:=lCode=0;
  end;

  function Textwerkzeug.istGanzeZahl(pText:string):boolean;
  var
    lganzeZahl:integer;
    lCode:integer;
  begin
    val(pText,lganzeZahl,lCode);
    result:=lCode=0;
  end;

  function Textwerkzeug.alsZahl(pText:string):double;
  var
    lZahl:double;
    lCode:integer;
  begin
    val(pText,lZahl,lCode);
    result:=lZahl;
  end;

  function Textwerkzeug.alsGanzeZahl(pText:string):integer;
  begin
    result:=strToInt(pText);
  end;

  function Textwerkzeug.alsText(pZahl:double):string;
  begin
    result:=floatToStr(pZahl);
  end;

  function Textwerkzeug.alsText(pGanzeZahl:integer):string;
  begin
    result:=intToStr(pGanzeZahl);
  end;

  function Textwerkzeug.verkettung(pText1, pText2:string):string;
  begin
    result:=pText1+pText2;
  end;

  function Textwerkzeug.dualInDezimal(pDualzahl:string):integer;
  var
    lZahl,lZaehler:integer;
  begin
    lZahl:=0;
    for lZaehler:=1 to length(pDualzahl) do
      if pDualzahl[lZaehler]='1' then
        lZahl:=lZahl*2+1
      else
        lZahl:=lZahl*2;
    result:=lZahl;
  end;

  function Textwerkzeug.dezimalInDual(pZahl:integer):string;
  var
    lDualzahl:string;
    lZaehler:integer;
  begin
    lDualzahl:='';
    repeat
      if pZahl mod 2 = 1 then
        lDualzahl:='1'+lDualzahl
      else
        lDualzahl:='0'+lDualzahl;
      pZahl:=pZahl div 2
    until pZahl=0;
    for lZaehler:=length(lDualzahl)+1 to 8 do
        lDualzahl:='0'+lDualzahl;
    result:=lDualzahl;
  end;

  destructor Textwerkzeug.gibFrei;
  begin end;


end.
 